<?php

namespace Autos\Dealer\Policies;

use Litepie\User\Contracts\UserPolicy;
use Autos\Dealer\Models\Dealer;

class DealerPolicy
{

    /**
     * Determine if the given user can view the dealer.
     *
     * @param UserPolicy $user
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function view(UserPolicy $user, Dealer $dealer)
    {
        if ($user->canDo('dealer.dealer.view') && $user->isAdmin()) {
            return true;
        }

        return $dealer->user_id == user_id() && $dealer->user_type == user_type();
    }

    /**
     * Determine if the given user can create a dealer.
     *
     * @param UserPolicy $user
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('dealer.dealer.create');
    }

    /**
     * Determine if the given user can update the given dealer.
     *
     * @param UserPolicy $user
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function update(UserPolicy $user, Dealer $dealer)
    {
        if ($user->canDo('dealer.dealer.edit') && $user->isAdmin()) {
            return true;
        }

        return $dealer->user_id == user_id() && $dealer->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given dealer.
     *
     * @param UserPolicy $user
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Dealer $dealer)
    {
        return $dealer->user_id == user_id() && $dealer->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given dealer.
     *
     * @param UserPolicy $user
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Dealer $dealer)
    {
        if ($user->canDo('dealer.dealer.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given dealer.
     *
     * @param UserPolicy $user
     * @param Dealer $dealer
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Dealer $dealer)
    {
        if ($user->canDo('dealer.dealer.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
